import { trumpAgents } from './agents.js';

let conversationHistory = [];
let isDiscussing = false;
let selectedAgent = null;
let autoDiscussionTimeout = null;

document.addEventListener('DOMContentLoaded', initializeChat);

function initializeChat() {
    const agentsContainer = document.getElementById('agents');
    trumpAgents.forEach(agent => {
        const agentCard = createAgentCard(agent);
        agentsContainer.appendChild(agentCard);
    });

    const input = document.getElementById('userInput');
    input.addEventListener('keypress', (e) => {
        if (e.key === 'Enter' && !e.shiftKey) {
            e.preventDefault();
            sendMessage();
        }
    });

    // Add initial greeting
    setTimeout(() => {
        addMessage("Welcome! I'm Donald Trump, and this is my wonderful family. We're here to chat with you about anything you'd like!", trumpAgents[0]);
        startAutoDiscussion();
    }, 1000);
}

function startAutoDiscussion() {
    if (autoDiscussionTimeout) {
        clearTimeout(autoDiscussionTimeout);
    }

    autoDiscussionTimeout = setTimeout(async () => {
        if (!isDiscussing && conversationHistory.length > 0) {
            const lastMessage = conversationHistory[conversationHistory.length - 1];
            const randomAgent = trumpAgents[Math.floor(Math.random() * trumpAgents.length)];
            
            await generateAndAddResponse(randomAgent, lastMessage.content, true);
        }
        startAutoDiscussion();
    }, 15000 + Math.random() * 10000);
}

async function generateAndAddResponse(agent, context, isAutoDiscussion = false) {
    if (isDiscussing) return;
    
    isDiscussing = true;
    const typingIndicator = showTypingIndicator(agent);
    await new Promise(resolve => setTimeout(resolve, 1000 + Math.random() * 1000));
    
    const response = await generateAgentResponse(agent, context);
    typingIndicator.remove();
    addMessage(response, agent);
    
    conversationHistory.push({
        role: 'assistant',
        agent: agent.name,
        content: response
    });

    isDiscussing = false;
}

function createAgentCard(agent) {
    const agentCard = document.createElement('div');
    agentCard.className = 'agent-card';
    agentCard.dataset.agentId = agent.id;
    agentCard.innerHTML = `
        ${agent.avatar}
        <div class="agent-info">
            <div class="agent-name">${agent.name}</div>
            <div class="agent-role">${agent.role}</div>
        </div>
    `;

    agentCard.addEventListener('click', () => {
        document.querySelectorAll('.agent-card').forEach(card => card.classList.remove('active'));
        agentCard.classList.add('active');
        selectedAgent = agent;
    });

    return agentCard;
}

function showTypingIndicator(agent) {
    const messagesContainer = document.getElementById('messages');
    const typingDiv = document.createElement('div');
    typingDiv.className = 'typing-indicator';
    typingDiv.innerHTML = `
        <div class="typing-dot"></div>
        <div class="typing-dot"></div>
        <div class="typing-dot"></div>
    `;
    messagesContainer.appendChild(typingDiv);
    messagesContainer.scrollTop = messagesContainer.scrollHeight;
    return typingDiv;
}

async function generateAgentResponse(agent, userInput) {
    try {
        const OPENROUTER_API_KEY = '<YOUR_OPENROUTER_API_KEY>'; // Replace with your actual API key
        const response = await fetch("https://openrouter.ai/api/v1/chat/completions", {
            method: "POST",
            headers: {
                "Authorization": `Bearer ${OPENROUTER_API_KEY}`,
                "Content-Type": "application/json"
            },
            body: JSON.stringify({
                "model": "openai/gpt-3.5-turbo",
                "messages": [
                    {
                        "role": "system",
                        "content": `You are ${agent.name}. Your personality is: ${agent.personality}. Engage in a conversation considering the context and maintain natural family dynamics.`
                    },
                    ...conversationHistory.slice(-10).map(msg => ({
                        "role": msg.role === 'user' ? 'user' : 'assistant',
                        "content": msg.content
                    })),
                    {
                        "role": "user",
                        "content": userInput
                    }
                ]
            })
        });

        const data = await response.json();

        if (response.ok) {
            const agentResponse = data.choices[0].message.content.trim();
            return agentResponse;
        } else {
            console.error('Error from API:', data);
            return `*${agent.name} is unable to respond at the moment.*`;
        }
    } catch (error) {
        console.error('Error:', error);
        return `*${agent.name} encountered an error.*`;
    }
}

function addMessage(content, agent = null, isUser = false) {
    const messagesContainer = document.getElementById('messages');
    const typingIndicators = messagesContainer.querySelectorAll('.typing-indicator');
    typingIndicators.forEach(indicator => indicator.remove());

    const messageDiv = document.createElement('div');
    messageDiv.className = `message ${isUser ? 'user' : 'ai'}`;
    
    messageDiv.innerHTML = `
        <div class="message-header">
            ${agent ? agent.avatar : ''}
            <strong>${isUser ? 'You' : agent.name}</strong>
        </div>
        <div class="message-content">${content}</div>
    `;
    
    messagesContainer.appendChild(messageDiv);
    messagesContainer.scrollTop = messagesContainer.scrollHeight;
}

window.sendMessage = async () => {
    const userInput = document.getElementById('userInput');
    if (!userInput.value.trim() || isDiscussing) return;
    
    const userMessage = userInput.value;
    addMessage(userMessage, null, true);
    userInput.value = '';
    
    conversationHistory.push({
        role: 'user',
        content: userMessage
    });

    // Have selected agent respond to user input
    if (selectedAgent) {
        await generateAndAddResponse(selectedAgent, userMessage);
    } else {
        // If no agent is selected, have all agents respond
        for (const agent of trumpAgents) {
            await generateAndAddResponse(agent, userMessage);
            await new Promise(resolve => setTimeout(resolve, 800));
        }
    }
    
    // Restart auto-discussion after user interaction
    startAutoDiscussion();
};